from helga.plugins import command

from functions import bounty_lookup, xur_lookup
from scraper import nightfall_info, heroic_info, daily_info, crucible_info, get_soup
from scraper import VENDOR_NAMES

nf_help = 'Displays info on the current nightfall from destinytracker.com'

@command('nightfall', aliases=('nf',), help=nf_help)
def nightfall(client, channel, nick, message, cmd, args):
    soup = get_soup()
    return nightfall_info(soup)

hero_help = 'Displays info on the current heroic from destinytracker.com'
@command('heroic', aliases=('hero',), help=hero_help)
def heroic(client, channel, nick, message, cmd, args):
    soup = get_soup()
    return heroic_info(soup)

daily_help = 'Displays info on the current heroic daily from planetdestiny.com'
@command('daily', aliases=(), help=daily_help)
def daily(client, channel, nick, message, cmd, args):
    return daily_info()

crucible_help = 'Displays info on the current daily crucible mode form planetdestiny.com'
@command('crucible', aliases=(), help=crucible_help)
def crucible(client, channel, nick, message, cmd, args):
    return crucible_info()

@command('xur', aliases=(), help="Gives a URL for looking up Xur's inventory")
def xur(client, channel, nick, message, cmd, args):
    return xur_lookup()

valid_names = ' ,'.join(VENDOR_NAMES)
bounty_help = "Looks up the bounties for a given vendor. Valid names are: %s" % valid_names
@command('bounties', aliases=('b',), help=bounty_help)
def bounties(client, channel, nick, message, cmd, args):
    vendor_name = args[0]

    if vendor_name.title() not in VENDOR_NAMES:
        return "Invalid vendor. Valid names are: %s" % valid_names

    return bounty_lookup(vendor_name)



from functools import partial
import requests
import bs4


template = "%(strike)s. Modifiers: %(mods)s"
event_url = 'http://destinytracker.com/destiny/events'

class ScrapeError(Exception):
    pass


def get_mods(soup, index):
    mod_list = soup.select('ul')[index]

    modifiers = [li.text for li in mod_list.select('li')]
    modifiers = ', '.join(modifiers)

    return modifiers


def get_soup(event_url=event_url):
    response = requests.get(event_url)
    html = response.text

    soup = bs4.BeautifulSoup(response.text)
    return soup


def strike_title(soup):
    title = soup.select('h4.media-heading')[-1].text
    return title


nightfall_mods = partial(get_mods, index=9)
heroic_mods = partial(get_mods, index=10)

def nightfall_info(soup):
    return template % {'strike': strike_title(soup),
                       'mods': nightfall_mods(soup)}


def heroic_info(soup):
    return template % {'strike': strike_title(soup),
                       'mods': heroic_mods(soup)}


def daily_info():
    soup = get_soup("http://db.planetdestiny.com/events")

    title = soup.select('div.activity-title')[0].text
    title = title.strip()

    mod_list = soup.select('div.tooltip-caption')[0:2]
    modifiers = [div.text for div in mod_list]
    modifiers = ', '.join(modifiers)

    return template % {'strike': title, 'mods': modifiers}


def crucible_info():
    soup = get_soup("http://db.planetdestiny.com/events")

    act_titles = soup.select('div.activity-title')
    mode_title = act_titles[1].text.strip()

    return "Daily Crucible mode: %s" % mode_title


BOUNTY_INDICES = {'eris': 0,
           'crucible': 1,
           'vanguard': 2,
}

VENDOR_NAMES = [v.title() for v in BOUNTY_INDICES.keys()]

def read_bounty_tables(vendor):

    soup = get_soup("http://db.planetdestiny.com/events")
    bounty_tables = soup.select('table')

    vendor = vendor.lower()

    try:
        index = BOUNTY_INDICES[vendor]
    except KeyError:
        raise ScrapeError("Vendor %s was not found" % vendor)

    table = bounty_tables[index]

    # The first row is the heading
    rows = table.select('tr')[1:]

    bounties = {}
    for row in rows:
        cells = row.select('td')
        name = cells[0].select('a')[0].text
        name = name.strip()

        desc = cells[1].text.strip()

        bounties[name] = desc

    return bounties


if __name__ == '__main__':
    #soup = get_soup()
    #print nightfall_info(soup)
    #print heroic_info(soup)
    #print daily_info()
    #print crucible_info()
    print bounty_info('Vanguard')
    print "---"
    print bounty_info('Crucible')
    print "---"
    print bounty_info('Eris')



from setuptools import setup, find_packages

setup(
    name='destiny_bot',
    version='0.0.13',
    description='Set of commands that scrape destinytracker.com for info.',
    author='Nolan Brubaker',
    author_email='palendae@gmail.com',
    packages=find_packages(),
    py_modules=['destiny_bot', 'scraper', 'functions'],
    include_package_data=True,
    zip_safe=True,
    install_requires=[
        'beautifulsoup4==4.3.2',
        'requests==2.2.1',
        'helga==1.6.4',
        'pytz',
    ],
    entry_points = dict(
        helga_plugins=[
            'nightfall = destiny_bot:nightfall',
            'heroic = destiny_bot:heroic',
            'daily = destiny_bot:daily',
            'crucible = destiny_bot:crucible',
            'xur = destiny_bot:xur',
            'bounties = destiny_bot:bounties',
        ]
    )
)
